# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html),
with one exception: small features that only simplify add a script to `scripts` can also be added in a patch release.

## [Unreleased]

### Added

- initial release of `pyROT` package
- initial release of `scripts`

### Fixed

### Deprecated

### Removed
